Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(122)

Unified Diff: sdk/lib/_internal/pub/test/serve/utils.dart

Issue 26284002: Rename "install" -> "get" and "update" -> "upgrade". (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/pub/test/serve/utils.dart
diff --git a/sdk/lib/_internal/pub/test/serve/utils.dart b/sdk/lib/_internal/pub/test/serve/utils.dart
index 8e3985c010b13026d9d7f3c66e27da24dfaf1f41..0a9a53ef7cd1896b08fef5394487c7bbd5ac126a 100644
--- a/sdk/lib/_internal/pub/test/serve/utils.dart
+++ b/sdk/lib/_internal/pub/test/serve/utils.dart
@@ -87,12 +87,12 @@ class DartTransformer extends Transformer {
/// Schedules starting the "pub serve" process.
///
/// If [shouldInstallFirst] is `true`, validates that pub install is run first.
/// If [dart2js] is `false`, does not compile Dart entrypoints in "web" to
/// JavaScript.
///
/// Returns the `pub serve` process.
-ScheduledProcess startPubServe({bool shouldInstallFirst: false,
+ScheduledProcess startPubServe({bool shouldGetFirst: false,
bool dart2js: true}) {
// Use port 0 to get an ephemeral port.
@@ -102,13 +102,13 @@ ScheduledProcess startPubServe({bool shouldInstallFirst: false,
_pubServer = startPub(args: args);
- if (shouldInstallFirst) {
+ if (shouldGetFirst) {
expect(_pubServer.nextLine(),
completion(startsWith("Dependencies have changed")));
expect(_pubServer.nextLine(),
completion(startsWith("Resolving dependencies...")));
expect(_pubServer.nextLine(),
- completion(equals("Dependencies installed!")));
+ completion(equals("Got dependencies!")));
}
expect(_pubServer.nextLine().then(_parsePort), completes);
@@ -87,12 +87,12 @@ class DartTransformer extends Transformer {
/// Schedules starting the "pub serve" process.
///
-/// If [shouldInstallFirst] is `true`, validates that pub install is run first.
-/// If [dart2js] is `false`, does not compile Dart entrypoints in "web" to
+/// If [shouldGetFirst] is `true`, validates that pub get is run first. If
+/// [dart2js] is `false`, does not compile Dart entrypoints in "web" to
/// JavaScript.
///

Powered by Google App Engine
This is Rietveld 408576698